@@ -81,21 +81,25 @@ static uint16_t *make_decoder_ref (const uint8_t **source)
 static int ljpeg_start (FILE *ifp, jhead *jh)
 {
 	int c, tag, len;
-	uint8_t data[0x10000];
+	uint8_t* data = malloc(0x10000);
 	const uint8_t *dp;
 
 	memset (jh, 0, sizeof(jhead));
 	jh->restart = 0x7FFFFFFF;
 	jh->zero_after_ff = 1;
 	fread (data, 2, 1, ifp);
-	if (data[1] != 0xd8) 
+	if (data[1] != 0xd8) {
+		free(data);
 		return 0;
+	}
 	do {
 		fread (data, 2, 2, ifp);
 		tag =  data[0] << 8 | data[1];
 		len = (data[2] << 8 | data[3]) - 2;
-		if (tag <= 0xff00) 
+		if (tag <= 0xff00) {
+			free(data);
 			return 0;
+		}
 		fread (data, 1, len, ifp);
 		switch (tag) 
 		{
@@ -108,7 +112,8 @@ static int ljpeg_start (FILE *ifp, jhead *jh)
 			jh->high = data[1] << 8 | data[2];
 			jh->wide = data[3] << 8 | data[4];
 			jh->clrs = data[5] + jh->sraw;
-			if (len == 9) getc(ifp);
+			if (len == 9) 
+				(void)getc(ifp);
 			break;
 		case 0xffc4:
 			/* DHT marker */
@@ -141,6 +146,7 @@ static int ljpeg_start (FILE *ifp, jhead *jh)
 			jh->huff[1+c] = jh->huff[0];
 	}
 	jh->row = (uint16_t *)cmpack_calloc (jh->wide*jh->clrs, 4);
+	free(data);
 	return 1;
 }
 
@@ -353,7 +359,7 @@ int crw_test(const char *block, size_t length, size_t filesize)
 }
 
 /* Read parameters from SBIG file */
-int crw_open(tHandle *handle, const char *filename, CmpackOpenMode flags)
+int crw_open(tHandle *handle, const char *filename, CmpackOpenMode mode, unsigned flags)
 {
 	int res = 0;
 	crwfile *raw;
@@ -697,12 +703,13 @@ int crw_copyheader(tHandle fs, CmpackImageHeader *hdr, CmpackChannel channel, Cm
 	/* Set date and time of observation */
 	if (src->date_time) {
 		memset(&dt, 0, sizeof(CmpackDateTime));
-		sscanf(src->date_time, "%4d:%2d:%2d %2d:%2d:%2d", &dt.date.year, &dt.date.month,
-			&dt.date.day, &dt.time.hour, &dt.time.minute, &dt.time.second);
-		sprintf(datestr, "%04d-%02d-%02d", dt.date.year, dt.date.month, dt.date.day);
-		ffpkys(dst,"DATE-OBS", (char*) datestr, "UT DATE OF START",&hdr->status);
-		sprintf(timestr, "%02d:%02d:%02d", dt.time.hour, dt.time.minute, dt.time.second);
-		ffpkys(dst,"TIME-OBS", (char*) timestr, "UT TIME OF START",&hdr->status);
+		if (sscanf(src->date_time, "%4d:%2d:%2d %2d:%2d:%2d", &dt.date.year, &dt.date.month,
+			&dt.date.day, &dt.time.hour, &dt.time.minute, &dt.time.second) == 6) {
+			sprintf(datestr, "%04d-%02d-%02d", dt.date.year, dt.date.month, dt.date.day);
+			ffpkys(dst, "DATE-OBS", (char*)datestr, "UT DATE OF START", &hdr->status);
+			sprintf(timestr, "%02d:%02d:%02d", dt.time.hour, dt.time.minute, dt.time.second);
+			ffpkys(dst, "TIME-OBS", (char*)timestr, "UT TIME OF START", &hdr->status);
+		}
 	}
 
 	/* Other parameters */
@@ -739,9 +746,10 @@ int crw_getdatetime(tHandle handle, CmpackDateTime *dt)
 
 	if (raw->date_time) {
 		memset(dt, 0, sizeof(CmpackDateTime));
-		sscanf(raw->date_time, "%4d:%2d:%2d %2d:%2d:%2d", &dt->date.year, &dt->date.month,
-			&dt->date.day, &dt->time.hour, &dt->time.minute, &dt->time.second);
-		return CMPACK_ERR_OK;
+		if (sscanf(raw->date_time, "%4d:%2d:%2d %2d:%2d:%2d", &dt->date.year, &dt->date.month,
+			&dt->date.day, &dt->time.hour, &dt->time.minute, &dt->time.second) == 6) {
+			return CMPACK_ERR_OK;
+		}
 	}
 	return CMPACK_ERR_KEY_NOT_FOUND;
 }
