@@ -58,7 +58,7 @@ static void *realloc_proc(void *ptr, size_t len)
 static int getdatetime(fitsfile *fits, CmpackDateTime *dt, int *end, int *center)
 {
 	int x, status, date_ok, time_ok;
-	char datestr[FLEN_VALUE], timestr[FLEN_VALUE], val[FLEN_VALUE], com[FLEN_COMMENT], *ptr;
+	char datestr[FLEN_VALUE], timestr[FLEN_VALUE], val[FLEN_VALUE], origin[FLEN_VALUE], instrume[FLEN_VALUE], telescop[FLEN_VALUE], camera[FLEN_VALUE], com[FLEN_COMMENT], *ptr;
 
 	memset(dt, 0, sizeof(CmpackDateTime));
 	*end = *center = 0;
@@ -101,8 +101,21 @@ static int getdatetime(fitsfile *fits, CmpackDateTime *dt, int *end, int *center
 		   Use the 'DATE' field here only if the CAMERA is QHY9 or QHY8L */
 		ffgkys(fits, "DATE", datestr, com, &status);
 		if (status == 0)
-			ffgkys(fits, "CAMERA", val, NULL, &status);
-		if (status != 0 || strcmp(com, "Capture Date") != 0 || (strcmp(val, "QHY9") != 0 && strcmp(val, "QHY8L") != 0)) { strcpy(datestr, ""); status = 0; }
+			ffgkys(fits, "CAMERA", camera, NULL, &status);
+		if (status != 0 || strcmp(com, "Capture Date") != 0 || (strcmp(camera, "QHY9") != 0 && strcmp(camera, "QHY8L") != 0)) { strcpy(datestr, ""); status = 0; }
+	}
+	if (*datestr == '\0') {
+		/* DATE    = '2018-12-20T09:52:32:262940' */
+		/* According to the FITS standard, this field indicates the date and time
+		   of the file creating.  */
+		ffgkys(fits, "DATE", datestr, com, &status);
+		if (status == 0)
+			ffgkys(fits, "ORIGIN", origin, NULL, &status);
+		if (status == 0)
+			ffgkys(fits, "INSTRUME", instrume, NULL, &status);
+		if (status == 0)
+			ffgkys(fits, "TELESCOP", telescop, NULL, &status);
+		if (status != 0 || strcmp(origin, "LAE") != 0 || strcmp(instrume, "PESTO") != 0 || strcmp(telescop, "OMM") != 0) { strcpy(datestr, ""); status = 0; }
 	}
 	if (*datestr == '\0') {
 		/* CTRLTIME= '2017-02-28 06:15:40.003439' */
@@ -246,6 +259,24 @@ static int getdatetime(fitsfile *fits, CmpackDateTime *dt, int *end, int *center
 			}
 		}
 	}
+	if (*timestr == '\0') {
+		/* DATE    = '2018-12-20T09:52:32:262940' */
+		/* According to the FITS standard, this field indicates the date and time
+		   of the file creating.  */
+		ffgkys(fits, "DATE", datestr, com, &status);
+		if (status == 0)
+			ffgkys(fits, "ORIGIN", origin, NULL, &status);
+		if (status == 0)
+			ffgkys(fits, "INSTRUME", instrume, NULL, &status);
+		if (status == 0)
+			ffgkys(fits, "TELESCOP", telescop, NULL, &status);
+		if (status != 0 || strcmp(origin, "LAE") != 0 || strcmp(instrume, "PESTO") != 0 || strcmp(telescop, "OMM") != 0) { strcpy(datestr, ""); status = 0; }
+		ptr = strchr(datestr, 'T');
+		if (ptr) {
+			/* yyyy-mm-ddThh:mm:ss.sss */
+			strcpy(timestr, ptr + 1);
+		}
+	}
 	if (*timestr == '\0') {
 		/* TM-START=  1.3079446944444E+01 / [Corrected] UT obs'n start, real hours */
 		ffgkys(fits, "TM-START", timestr, NULL, &status);
@@ -321,7 +352,15 @@ static int getdatetime(fitsfile *fits, CmpackDateTime *dt, int *end, int *center
 	}
 
     time_ok = 0;
-	if ((strlen(timestr) >= 8) && (((timestr[2] == ':') && (timestr[5] == ':')) || ((timestr[2] == '.') && (timestr[5] == '.')))) {
+	if ((strlen(timestr) == 8) && (((timestr[2] == ':') && (timestr[5] == ':')) || ((timestr[2] == '.') && (timestr[5] == '.')))) {
+		/* HH:MM:SS or HH.MM.SS */
+		dt->time.hour = atol(timestr);
+		dt->time.minute = atol(timestr + 3);
+		dt->time.second = atol(timestr + 6);
+		dt->time.milisecond = 0;
+		time_ok = 1;
+	}
+	if (!time_ok && (strlen(timestr) >= 10) && (((timestr[2] == ':') && (timestr[5] == ':')) || ((timestr[2] == '.') && (timestr[5] == '.'))) && (timestr[8] == '.')) {
 		/* HH:MM:SS.SSSS or HH.MM.SS.SSSS */
 		dt->time.hour = atol(timestr);
 		dt->time.minute = atol(timestr + 3);
@@ -330,11 +369,39 @@ static int getdatetime(fitsfile *fits, CmpackDateTime *dt, int *end, int *center
 		dt->time.milisecond = x % 1000;
 		time_ok = 1;
 	}
-	if (!time_ok && (strlen(timestr) >= 7) && (((timestr[1] == ':') && (timestr[4] == ':')) || ((timestr[1] == '.') && (timestr[4] == '.')))) {
+	if (!time_ok && (strlen(timestr) >= 10) && (timestr[2] == ':') && (timestr[5] == ':') && (timestr[8] == ':')) {
+		/* HH:MM:SS:SSSS */
+		timestr[8] = '.';
+		dt->time.hour = atol(timestr);
+		dt->time.minute = atol(timestr + 3);
+		x = (int)(1000.0 * atof(timestr + 6) + 0.5);
+		dt->time.second = x / 1000;
+		dt->time.milisecond = x % 1000;
+		time_ok = 1;
+	}
+	if (!time_ok && (strlen(timestr) == 7) && (((timestr[1] == ':') && (timestr[4] == ':')) || ((timestr[1] == '.') && (timestr[4] == '.')))) {
+		/* H:MM:SS or H.MM.SS */
+		dt->time.hour = atol(timestr);
+		dt->time.minute = atol(timestr + 2);
+		dt->time.second = atol(timestr + 5);
+		dt->time.milisecond = 0;
+		time_ok = 1;
+	}
+	if (!time_ok && (strlen(timestr) >= 9) && (((timestr[1] == ':') && (timestr[4] == ':')) || ((timestr[1] == '.') && (timestr[4] == '.'))) && (timestr[7] == '.')) {
 		/* H:MM:SS.SSSS or H.MM.SS.SSSS*/
 		dt->time.hour = atol(timestr);
 		dt->time.minute = atol(timestr + 2);
-		x = (int)(1000.0*atof(timestr + 5) + 0.5);
+		x = (int)(1000.0 * atof(timestr + 5) + 0.5);
+		dt->time.second = x / 1000;
+		dt->time.milisecond = x % 1000;
+		time_ok = 1;
+	}
+	if (!time_ok && (strlen(timestr) >= 9) && (((timestr[1] == ':') && (timestr[4] == ':')) || ((timestr[1] == '.') && (timestr[4] == '.'))) && (timestr[7] == ':')) {
+		/* H:MM:SS.SSSS or H.MM.SS.SSSS*/
+		timestr[7] = '.';
+		dt->time.hour = atol(timestr);
+		dt->time.minute = atol(timestr + 2);
+		x = (int)(1000.0 * atof(timestr + 5) + 0.5);
 		dt->time.second = x / 1000;
 		dt->time.milisecond = x % 1000;
 		time_ok = 1;
@@ -722,7 +789,9 @@ char *fits_getfilter(tHandle handle, CmpackChannel channel)
 	if (ffgkys(fs->fits, "FILTERS", value, NULL, &status)==0) 
 		return cmpack_strdup(value);
 	status = 0;
-	
+	if (ffgkys(fs->fits, "FILTRE", value, NULL, &status) == 0)
+		return cmpack_strdup(value);
+
 	return NULL;
 }
 
@@ -830,6 +899,10 @@ char *fits_getobserver(tHandle handle)
 	status = 0;
 	if (ffgkys(fs->fits, "OBSERVER", value, NULL, &status)==0 && *value!='\0')
 		return cmpack_strdup(value);
+	status = 0;
+	if (ffgkys(fs->fits, "OBSERV", value, NULL, &status) == 0 && *value != '\0')
+		return cmpack_strdup(value);
+
 	return NULL;
 }
 
@@ -1054,6 +1127,13 @@ int fits_getccdtemp(tHandle handle, double *temp)
 		}
 		return 0;
 	}
+	status = 0;
+	if (ffgkys(fs->fits, "TMESDECT", buf, NULL, &status) == 0) {
+		if (temp) 
+			*temp = atof(buf);
+		return 0;
+	}
+
 	return CMPACK_ERR_KEY_NOT_FOUND;
 }
 
