@@ -2484,7 +2484,7 @@ bool CExportCatFileDlg::Execute(const CCatalog &file, const CTags &tags, const C
 	// File types
 	gtk_combo_box_set_model(GTK_COMBO_BOX(m_TypeCombo), NULL);
 	gtk_list_store_clear(m_FileTypes);
-	for (int i=0; FileFormats[i].Caption; i++) {
+	for (int i=0; FileFormats[i].Id != NULL; i++) {
 		GtkTreeIter iter;
 		gtk_list_store_append(m_FileTypes, &iter);
 		gtk_list_store_set(m_FileTypes, &iter, 0, i, 1, FileFormats[i].Caption, -1);
