@@ -1432,19 +1432,18 @@ void CLocation::Clear()
 bool CLocation::Valid(void) const
 {
 	double x, y;
-
-	if (m_Lon && m_Lat && *m_Lon!='\0' && *m_Lat!='\0') 
-		return cmpack_strtolon(m_Lon, &x)==0 && cmpack_strtolat(m_Lat, &y)==0;
+	if (m_Lon && m_Lat && *m_Lon != '\0' && *m_Lat != '\0')
+		return cmpack_strtolon(m_Lon, &x) == 0 && cmpack_strtolat(m_Lat, &y) == 0;
 	return false;
 }
 
 //
 // Comparison operators
 //
-bool operator==(const CLocation &a, const CLocation &b)
+bool operator==(const CLocation& a, const CLocation& b)
 {
-	return StrCmp0(a.m_Name, b.m_Name)==0 &&
-		StrCmp0(a.m_Lon, b.m_Lon)==0 && StrCmp0(a.m_Lat, b.m_Lat)==0;
+	return StrCmp0(a.m_Name, b.m_Name) == 0 &&
+		StrCmp0(a.m_Lon, b.m_Lon) == 0 && StrCmp0(a.m_Lat, b.m_Lat) == 0;
 }
 
 //------------------------   FILE INFO   --------------------------
@@ -1532,6 +1531,7 @@ void CFileInfo::Clear(void)
 void CFileInfo::Load(GKeyFile *cfg, const gchar *section, const gchar *prefix)
 {
 	gchar key[128], *val;
+	int time[2];
 
 	Clear();
 
@@ -1545,10 +1545,9 @@ void CFileInfo::Load(GKeyFile *cfg, const gchar *section, const gchar *prefix)
 	val = g_key_file_get_string(cfg, section, key, NULL);
 	if (val && *val!='\0') {
 		if (sizeof(time_t)==sizeof(int)) 
-			sscanf(val, " %11d ", (int*)&m_MTime);
+			(void)sscanf(val, " %11d ", (int*)&m_MTime);
 		else {
-			int time[2];
-			sscanf(val, " %11d %11d", time, time+1);
+			(void)sscanf(val, " %11d %11d", time, time+1);
 			memcpy(&m_MTime, time, 2*sizeof(int));
 		}
 	}
@@ -1769,12 +1768,14 @@ CFrameInfo::~CFrameInfo(void)
 //
 // Initialization
 //
-bool CFrameInfo::Init(const gchar *filepath, GError **error)
+bool CFrameInfo::Init(const gchar *filepath, const CProfile* profile, GError **error)
 {
 	Clear();
 
+	bool positiveWest = (profile ? profile->GetBool(CProfile::POSITIVE_WEST) : CConfig::GetBool(CConfig::POSITIVE_WEST));
+
 	CCCDFile file;
-	if (!file.Open(filepath, CMPACK_OPEN_READONLY, error)) 
+	if (!file.Open(filepath, CMPACK_OPEN_READONLY, (!positiveWest ? 0 : CMPACK_OPENF_POSITIVE_WEST), error))
 		return false;
 
 	m_FullPath = CopyString(filepath);
