@@ -31,6 +31,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #define MAX_TAG_SIZE 1023
 
+class CProfile;
+
 // Cell index
 struct tIndex {
 	int col, row;
@@ -441,7 +443,7 @@ public:
 	void Clear(void);
 
 	// Initialize data
-	bool Init(const gchar *filepath, GError **error = 0);
+	bool Init(const gchar *filepath, const CProfile* profile, GError **error = 0);
 
 	// Is the data valid?
 	bool Valid() const
