@@ -307,8 +307,8 @@ bool CLoadProfileDlg::OnCloseQuery(void)
 {
 	GtkTreeModel *model;
 	GtkTreeIter iter;
-	gchar *path;
-	gboolean userDefined;
+	gchar *path = NULL;
+	gboolean userDefined = 0;
 
 	m_Profile.Clear();
 	
@@ -729,7 +729,7 @@ gboolean CImportProfileDlg::OnRecentFilter(const GtkRecentFilterInfo *filter_inf
 // Constructor
 //
 CSaveProfileDlg::CSaveProfileDlg(GtkWindow *pParent, tAction action):m_Action(action),
-	m_Profiles(NULL), m_Path(NULL), m_OldName(NULL)
+	m_Profiles(NULL), m_Path(NULL), m_OldName(NULL), m_OptionsBtn(NULL)
 {
 	// Dialog with buttons
 	m_pDlg = gtk_dialog_new_with_buttons(NULL, pParent, 
