@@ -510,7 +510,7 @@ void CMatchingMTTab::UpdatePreview(bool force_update)
 					UpdateChart(pht);
 				g_free(pht_file);
 				gchar *fts_file = g_Project->GetImageFile(path);
-				CImage *img = CImage::fromFile(fts_file);
+				CImage *img = CImage::fromFile(fts_file, g_Project->Profile());
 				if (img) {
 					UpdateImage(img);
 					delete img;
@@ -988,7 +988,7 @@ bool CChooseTargetDlg::Execute(GtkTreePath *path, int &objectID, GError **error)
 		UpdateChart();
 		gchar *fts_file = g_Project->GetImageFile(path);
 		if (fts_file) {
-			m_Image = CImage::fromFile(fts_file, CMPACK_BITPIX_AUTO);
+			m_Image = CImage::fromFile(fts_file, g_Project->Profile(), CMPACK_BITPIX_AUTO);
 			UpdateImage();
 			g_free(fts_file);
 		}
