@@ -235,7 +235,7 @@ bool CNewFilesChecker::CheckNewFile(const gchar *filepath, bool *try_again)
 	if (!m_Prefix || CheckFileName(basename, m_Prefix)) {
 		if (!g_Project->FileInProject(filepath)) {
 			GError *error = NULL;
-			if (!info.Init(filepath, &error)) {
+			if (!info.Init(filepath, g_Project->Profile(), &error)) {
 				if (error) {
 					*try_again = (error->code==CMPACK_ERR_CANT_OPEN_SRC);
 					g_error_free(error);
