@@ -332,12 +332,13 @@ void CLocationDlg::SetUserData(const CLocation *data)
 {
 	char buf[64];
 	double lon, lat;
+	int positiveWest = (g_Project->Profile()->GetBool(CProfile::POSITIVE_WEST) ? 1 : 0);
 
 	if (data->Name()) 
 		gtk_entry_set_text(GTK_ENTRY(m_EntryName), data->Name());
 	else
 		gtk_entry_set_text(GTK_ENTRY(m_EntryName), "");
-	if (cmpack_strtolon(data->Lon(), &lon)==0) {
+	if (cmpack_strtolon2(data->Lon(), positiveWest, &lon)==0) {
 		cmpack_lontostr(lon, buf, 64);
 		gtk_entry_set_text(GTK_ENTRY(m_EntryLon), buf);
 	} else
@@ -360,13 +361,14 @@ void CLocationDlg::SetDefData(const CLocation &data)
 {
 	char buf[64];
 	double lon, lat;
+	int positiveWest = (g_Project->Profile()->GetBool(CProfile::POSITIVE_WEST) ? 1 : 0);
 
 	gtk_widget_set_sensitive(m_DefBtn, data.Valid());
 	if (data.Name()) 
 		gtk_entry_set_text(GTK_ENTRY(m_DefName), data.Name());
 	else
 		gtk_entry_set_text(GTK_ENTRY(m_DefName), "");
-	if (cmpack_strtolon(data.Lon(), &lon)==0) {
+	if (cmpack_strtolon2(data.Lon(), positiveWest, &lon)==0) {
 		cmpack_lontostr(lon, buf, 64);
 		gtk_entry_set_text(GTK_ENTRY(m_DefLon), buf);
 	} else
@@ -387,13 +389,14 @@ void CLocationDlg::SetRefData(const CLocation *data)
 {
 	char buf[64];
 	double lon, lat;
+	int positiveWest = (g_Project->Profile()->GetBool(CProfile::POSITIVE_WEST) ? 1 : 0);
 
 	gtk_widget_set_sensitive(m_RefBtn, data->Valid());
 	if (data->Name()) 
 		gtk_entry_set_text(GTK_ENTRY(m_RefName), data->Name());
 	else
 		gtk_entry_set_text(GTK_ENTRY(m_RefName), "");
-	if (cmpack_strtolon(data->Lon(), &lon)==0) {
+	if (cmpack_strtolon2(data->Lon(), positiveWest, &lon)==0) {
 		cmpack_lontostr(lon, buf, 64);
 		gtk_entry_set_text(GTK_ENTRY(m_RefLon), buf);
 	} else
@@ -413,6 +416,7 @@ bool CLocationDlg::GetData(CLocation *data, bool name_required)
 	const gchar *name, *lon, *lat, *remarks;
 	char buf[64];
 	double x, y;
+	int positiveWest = (g_Project->Profile()->GetBool(CProfile::POSITIVE_WEST) ? 1 : 0);
 
 	data->Clear();
 	name = lon = lat = remarks = NULL;
@@ -445,7 +449,7 @@ bool CLocationDlg::GetData(CLocation *data, bool name_required)
 		ShowError(GTK_WINDOW(m_pDlg), "Please, enter the observer's latitude.");
 		return false;
 	}
-	if (cmpack_strtolon(lon, &x)!=0) {
+	if (cmpack_strtolon2(lon, positiveWest, &x)!=0) {
 		ShowError(GTK_WINDOW(m_pDlg), "Invalid value of longitude");
 		return false;
 	}
