@@ -491,10 +491,10 @@ void CPreview::LoadProject(const char *filename)
 			bool rows_upward = CConfig::GetBool(CConfig::ROWS_UPWARD);
 			cmpack_preview_set_image_orientation(CMPACK_PREVIEW(m_Preview), rows_upward ? CMPACK_ROWS_UPWARDS : CMPACK_ROWS_DOWNWARDS);
 			gchar *ftemp = prj.GetImageFile(first);
-			CImage *img = CImage::fromFile(ftemp);
+			CImage *img = CImage::fromFile(ftemp, NULL);
 			if (!img) {
 				gchar *forig = prj.GetSourceFile(first);
-				img = CImage::fromFile(forig);
+				img = CImage::fromFile(forig, NULL);
 				g_free(forig);
 			}
 			if (img)
