@@ -866,7 +866,7 @@ void CTableDlg::Export()
 // Constructor
 //
 CTableInfoDlg::CTableInfoDlg(GtkWindow *pParent):CInfoDlg(pParent, 0),
-	m_Name(NULL)
+	m_Name(NULL), m_File(NULL)
 {
 	GtkWidget *bbox;
 
