@@ -238,8 +238,7 @@ static int make_light_curve()
 			if (din==NULL) error(CMPACK_ERR_CANT_OPEN_DIRFILE, dirfile_in);
 		}
 		while (fgets(buf1, MAXLINE, din)) {
-			sscanf(buf1, "%1023s", line);
-			if (CheckFilePath(line)) {
+			if (sscanf(buf1, "%1023s", line) == 1 && CheckFilePath(line)) {
 				in_files++;
 				list(fset, line, frame_id++);
 			}
@@ -334,8 +333,7 @@ static int make_track_curve()
 			if (din==NULL) error(CMPACK_ERR_CANT_OPEN_DIRFILE, dirfile_in);
 		}
 		while (fgets(buf1, MAXLINE, din)) {
-			sscanf(buf1, "%1023s", line);
-			if (CheckFilePath(line)) {
+			if (sscanf(buf1, "%1023s", line) == 1 && CheckFilePath(line)) {
 				in_files++;
 				list(fset, line, frame_id++);
 			}
@@ -466,8 +464,7 @@ static int make_obj_plot()
 			if (din==NULL) error(CMPACK_ERR_CANT_OPEN_DIRFILE, dirfile_in);
 		}
 		while (fgets(buf1, MAXLINE, din)) {
-			sscanf(buf1, "%1023s", line);
-			if (CheckFilePath(line)) {
+			if (sscanf(buf1, "%1023s", line) == 1 && CheckFilePath(line)) {
 				in_files++;
 				list(fset, line, frame_id++);
 			}
@@ -651,12 +648,13 @@ static int make_chart()
 			din = fopen(dirfile_in, "r");
 			if (din==NULL) error(CMPACK_ERR_CANT_OPEN_DIRFILE, dirfile_in);
 		}
-		while (fgets(buf1, MAXLINE, din)) {
-			sscanf(buf1, "%1023s", line);
-			if (CheckFilePath(line)) {
-				in_files++;
-				dump(line, output, aperture);
-				break;
+		if (din) {
+			while (fgets(buf1, MAXLINE, din)) {
+				if (sscanf(buf1, "%1023s", line) == 1 && CheckFilePath(line)) {
+					in_files++;
+					dump(line, output, aperture);
+					break;
+				}
 			}
 		}
 		if (din && din!=stdin)
